@@ -18,6 +18,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -26,8 +30,6 @@
 
 #include <pthread.h>
 
-#include <config.h>
-
 #include <sndfile.h>
 
 #define BUFFER_LEN 1024
@@ -187,7 +189,7 @@ static sndfile_format_caps format_caps[] = {
 typedef struct {
   gboolean saving; /* loading or saving ? */
   sw_sample * sample;
-  char * pathname;
+  gchar * pathname;
   SF_INFO * sfinfo;
 #if 0
   GtkWidget * radio_mono;
@@ -246,7 +248,7 @@ get_subformat_caps (sndfile_subformat_caps * format_subcaps, int subformat)
 }
 
 static void
-sweep_sndfile_perror (SNDFILE * sndfile, char * pathname)
+sweep_sndfile_perror (SNDFILE * sndfile, gchar * pathname)
 {
 #undef BUF_LEN
 #define BUF_LEN 128
@@ -401,7 +403,7 @@ set_subformat_cb (GtkWidget * widget, gpointer data)
   sfinfo->format &= SF_FORMAT_TYPEMASK; /* clear submask */
 
   subformat = 
-    GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(widget)));
+    GPOINTER_TO_INT(g_object_get_data (G_OBJECT(widget), "default"));
   subformat &= SF_FORMAT_SUBMASK; /* get new subformat */
 
   sfinfo->format |= subformat;
@@ -416,7 +418,7 @@ set_bits_cb (GtkWidget * widget, gpointer data)
   SF_INFO * sfinfo = so->sfinfo;
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget))) {
-    sfinfo->pcmbitwidth = (int) gtk_object_get_user_data (GTK_OBJECT(widget));
+    sfinfo->pcmbitwidth = (int) g_object_get_data (G_OBJECT(widget), "default");
   }
 
   update_ok_button (so);
@@ -449,7 +451,7 @@ set_channels_cb (GtkWidget * widget, gint channels, gpointer data)
 
 #if 0
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget))) {
-    sfinfo->channels = (int) gtk_object_get_user_data (GTK_OBJECT(widget));
+    sfinfo->channels = (int) g_object_get_data (G_OBJECT(widget), "default");
   }
 #else
   sfinfo->channels = channels;
@@ -477,7 +479,7 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
   GtkWidget * ok_button, * button;
   GtkWidget * radio;
 
-  GtkStyle * style;
+/*GtkStyle * style;*/
 
   GtkTooltips * tooltips;
 
@@ -490,6 +492,8 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
   dialog = gtk_dialog_new ();
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
 
+   attach_window_close_accel(GTK_WINDOW(dialog));
+
   /* Set up the action area first so the sensitivity of the ok button
    *  can be updated by formats below. */
 
@@ -510,8 +514,8 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->action_area), button,
 		      TRUE, TRUE, 0);
   gtk_widget_show (button);
-  gtk_signal_connect (GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC (sndfile_save_options_dialog_cancel_cb),
+  g_signal_connect (G_OBJECT(button), "clicked",
+		      G_CALLBACK (sndfile_save_options_dialog_cancel_cb),
 		      so);
 
 
@@ -541,18 +545,20 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
 
   /* Filename */
 
+/* pangoise?
+
   style = gtk_style_copy (style_wb);
   gdk_font_unref (style->font);
   style->font =
-    gdk_font_load("-*-helvetica-medium-r-normal-*-*-180-*-*-*-*-*-*");
+  gdk_font_load("-*-helvetica-medium-r-normal-*-*-180-*-*-*-*-*-*");
   gtk_widget_push_style (style);
-
+*/
   label = gtk_label_new (g_basename (so->pathname));
   gtk_box_pack_start (GTK_BOX(vbox), label,
 		      FALSE, FALSE, 8);
   gtk_widget_show (label);
   
-  gtk_widget_pop_style ();
+/*gtk_widget_pop_style ();*/
 
   notebook = gtk_notebook_new ();
   gtk_box_pack_start (GTK_BOX(main_vbox), notebook, TRUE, TRUE, 4);
@@ -600,10 +606,10 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
     while (fcaps && (fcaps->subformat != 0)) {
       name = get_subformat_name(fcaps->subformat);
       menuitem = gtk_menu_item_new_with_label (name);
-      gtk_object_set_user_data (GTK_OBJECT(menuitem),
+      g_object_set_data (G_OBJECT(menuitem), "default", 
 				GINT_TO_POINTER(fcaps->subformat));
-      gtk_signal_connect (GTK_OBJECT(menuitem), "activate",
-			  GTK_SIGNAL_FUNC(set_subformat_cb), so);
+      g_signal_connect (G_OBJECT(menuitem), "activate",
+			  G_CALLBACK(set_subformat_cb), so);
       gtk_menu_append (GTK_MENU(menu), menuitem);
       gtk_widget_show (menuitem);
       if (fcaps->subformat == subformat) {
@@ -625,8 +631,8 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
 		      GTK_FILL|GTK_EXPAND, GTK_SHRINK, 0, 0);
     gtk_widget_show (entry);
 
-    gtk_signal_connect (GTK_OBJECT(entry), "number-changed",
-			GTK_SIGNAL_FUNC(set_rate_cb), so);
+    g_signal_connect (G_OBJECT(entry), "number-changed",
+			G_CALLBACK(set_rate_cb), so);
 
     if (sample == NULL)
       so->sfinfo->samplerate = samplerate_chooser_get_rate (entry);
@@ -677,7 +683,7 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
     snprintf (buf, BUF_LEN, "%d", 44100);
     gtk_entry_set_text (GTK_ENTRY (entry), buf); 
 
-    gtk_signal_connect (GTK_OBJECT(entry), "changed", set_rate_cb, so);
+    g_signal_connect (G_OBJECT(entry), "changed", G_CALLBACK(set_rate_cb), so);
 
     label = gtk_label_new ("Hz");
     gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -698,8 +704,8 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
 		    GTK_FILL|GTK_EXPAND, GTK_SHRINK, 0, 0);
   gtk_widget_show (entry);
   
-  gtk_signal_connect (GTK_OBJECT(entry), "number-changed",
-		      GTK_SIGNAL_FUNC(set_channels_cb), so);
+  g_signal_connect (G_OBJECT(entry), "number-changed",
+		      G_CALLBACK(set_channels_cb), so);
 
   if (sample == NULL)
     so->sfinfo->channels = channelcount_chooser_get_count (entry);
@@ -727,9 +733,9 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
     radio = gtk_radio_button_new_with_label (NULL, _("Mono (mixdown)"));
   }
   gtk_box_pack_start (GTK_BOX(hbox), radio, TRUE, TRUE, 0);
-  gtk_object_set_user_data (GTK_OBJECT(radio), (gpointer)1);
-  gtk_signal_connect (GTK_OBJECT(radio), "toggled",
-		      set_channels_cb, so);
+  g_object_set_data (G_OBJECT(radio), "default", (gpointer)1);
+  g_signal_connect (G_OBJECT(radio), "toggled",
+		      G_CALLBACK(set_channels_cb), so);
   gtk_widget_show (radio);
 
   so->radio_mono = radio;
@@ -743,9 +749,9 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
        _("Stereo (duplicate)"));
   }
   gtk_box_pack_start (GTK_BOX(hbox), radio, TRUE, TRUE, 0);
-  gtk_object_set_user_data (GTK_OBJECT(radio), (gpointer)2);
-  gtk_signal_connect (GTK_OBJECT(radio), "toggled",
-		      set_channels_cb, so);
+  g_object_set_data (G_OBJECT(radio), "default", (gpointer)2);
+  g_signal_connect (G_OBJECT(radio), "toggled",
+		      G_CALLBACK(set_channels_cb), so);
   gtk_widget_show (radio);
 
   so->radio_stereo = radio;
@@ -769,9 +775,9 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
 
   radio = gtk_radio_button_new_with_label (NULL, _("8 bit"));
   gtk_box_pack_start (GTK_BOX(hbox), radio, FALSE, FALSE, 0);
-  gtk_object_set_user_data (GTK_OBJECT(radio), (gpointer)8);
-  gtk_signal_connect (GTK_OBJECT(radio), "toggled",
-		      set_bits_cb, so);
+  g_object_set_data (G_OBJECT(radio), "default", (gpointer)8);
+  g_signal_connect (G_OBJECT(radio), "toggled",
+		      G_CALLBACK(set_bits_cb), so);
   gtk_widget_show (radio);
 
   so->radio_8bit = radio;
@@ -779,9 +785,9 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
   radio = gtk_radio_button_new_with_label
     (gtk_radio_button_group (GTK_RADIO_BUTTON(radio)), _("16 bit"));
   gtk_box_pack_start (GTK_BOX(hbox), radio, FALSE, FALSE, 0);
-  gtk_object_set_user_data (GTK_OBJECT(radio), (gpointer)16);
-  gtk_signal_connect (GTK_OBJECT(radio), "toggled",
-		      set_bits_cb, so);
+  g_object_set_data (G_OBJECT(radio), "default", (gpointer)16);
+  g_signal_connect (G_OBJECT(radio), "toggled",
+		      G_CALLBACK(set_bits_cb), so);
   gtk_widget_show (radio);
 
   so->radio_16bit = radio;
@@ -789,9 +795,9 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
   radio = gtk_radio_button_new_with_label
     (gtk_radio_button_group (GTK_RADIO_BUTTON(radio)), _("24 bit"));
   gtk_box_pack_start (GTK_BOX(hbox), radio, FALSE, FALSE, 0);
-  gtk_object_set_user_data (GTK_OBJECT(radio), (gpointer)24);
-  gtk_signal_connect (GTK_OBJECT(radio), "toggled",
-		      set_bits_cb, so);
+  g_object_set_data (G_OBJECT(radio), "default", (gpointer)24);
+  g_signal_connect (G_OBJECT(radio), "toggled",
+		      G_CALLBACK(set_bits_cb), so);
   gtk_widget_show (radio);
 
   so->radio_24bit = radio;
@@ -799,9 +805,9 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
   radio = gtk_radio_button_new_with_label
     (gtk_radio_button_group (GTK_RADIO_BUTTON(radio)), _("32 bit"));
   gtk_box_pack_start (GTK_BOX(hbox), radio, FALSE, FALSE, 0);
-  gtk_object_set_user_data (GTK_OBJECT(radio), (gpointer)32);
-  gtk_signal_connect (GTK_OBJECT(radio), "toggled",
-		      set_bits_cb, so);
+  g_object_set_data (G_OBJECT(radio), "default", (gpointer)32);
+  g_signal_connect (G_OBJECT(radio), "toggled",
+		      G_CALLBACK(set_bits_cb), so);
   gtk_widget_show (radio);
 
   so->radio_32bit = radio;
@@ -852,7 +858,7 @@ create_sndfile_encoding_options_dialog (sndfile_save_options * so)
 }
 
 int
-sndfile_save_options_dialog (sw_sample * sample, char * pathname)
+sndfile_save_options_dialog (sw_sample * sample, gchar * pathname)
 {
   GtkWidget * dialog;
   sndfile_save_options * so;
@@ -905,8 +911,8 @@ sndfile_save_options_dialog (sw_sample * sample, char * pathname)
   dialog = create_sndfile_encoding_options_dialog (so);
   gtk_window_set_title (GTK_WINDOW(dialog), _("Sweep: Save PCM options"));
 
-  gtk_signal_connect (GTK_OBJECT(so->ok_button), "clicked",
-		      GTK_SIGNAL_FUNC (sndfile_save_options_dialog_ok_cb),
+  g_signal_connect (G_OBJECT(so->ok_button), "clicked",
+		      G_CALLBACK (sndfile_save_options_dialog_ok_cb),
 		      so);
 
   gtk_widget_show (dialog);
@@ -922,7 +928,7 @@ struct _sf_data {
 };
 
 static sw_sample *
-_sndfile_sample_load (sw_sample * sample, char * pathname, SF_INFO * sfinfo,
+_sndfile_sample_load (sw_sample * sample, gchar * pathname, SF_INFO * sfinfo,
 		      gboolean try_raw);
 
 static void
@@ -930,7 +936,7 @@ sndfile_load_options_dialog_ok_cb (GtkWidget * widget, gpointer data)
 {
   sndfile_save_options * so = (sndfile_save_options *)data;
   sw_sample * sample = so->sample;
-  char * pathname = so->pathname;
+  gchar * pathname = so->pathname;
   SF_INFO * sfinfo = so->sfinfo;
   GtkWidget * dialog;
 
@@ -1020,7 +1026,7 @@ static sw_operation sndfile_load_op = {
 };
 
 static sw_sample *
-_sndfile_sample_load (sw_sample * sample, char * pathname, SF_INFO * sfinfo,
+_sndfile_sample_load (sw_sample * sample, gchar * pathname, SF_INFO * sfinfo,
 		      gboolean try_raw)
 {
   SNDFILE * sndfile;
@@ -1069,8 +1075,8 @@ _sndfile_sample_load (sw_sample * sample, char * pathname, SF_INFO * sfinfo,
       gtk_window_set_title (GTK_WINDOW(dialog),
 			    _("Sweep: Load Raw PCM options"));
 
-      gtk_signal_connect (GTK_OBJECT(so->ok_button), "clicked",
-			  GTK_SIGNAL_FUNC (sndfile_load_options_dialog_ok_cb),
+      g_signal_connect (G_OBJECT(so->ok_button), "clicked",
+			  G_CALLBACK (sndfile_load_options_dialog_ok_cb),
 			  so);
 
       gtk_widget_show (dialog);
@@ -1138,7 +1144,7 @@ sndfile_sample_reload (sw_sample * sample, gboolean try_raw)
 }
 
 sw_sample *
-sndfile_sample_load (char * pathname, gboolean try_raw)
+sndfile_sample_load (gchar * pathname, gboolean try_raw)
 {
   if (pathname == NULL) return NULL;
 
@@ -1149,7 +1155,7 @@ static int
 sndfile_sample_save_thread (sw_op_instance * inst)
 {
   sw_sample * sample = inst->sample;
-  char * pathname = (char *)inst->do_data;
+  gchar * pathname = (char *)inst->do_data;
 
   SNDFILE *sndfile;
   SF_INFO * sfinfo;
@@ -1337,7 +1343,7 @@ static sw_operation sndfile_save_op = {
 };
 
 int
-sndfile_sample_save (sw_sample * sample, char * pathname)
+sndfile_sample_save (sw_sample * sample, gchar * pathname)
 {
   char buf[BUF_LEN];
 
