@@ -70,10 +70,17 @@
 #include <ctype.h>
 
 #include <ogg/ogg.h>
+#ifdef HAVE_SPEEX_SUBDIR
+#include <speex/speex.h>
+#include <speex/speex_header.h>
+#include <speex/speex_stereo.h>
+#include <speex/speex_callbacks.h>
+#else
 #include <speex.h>
 #include <speex_header.h>
 #include <speex_stereo.h>
 #include <speex_callbacks.h>
+#endif
 
 #define BUFFER_LEN 1024
 
@@ -98,6 +105,7 @@
 #include "view.h"
 
 #include "../pixmaps/xifish.xpm"
+#include "../pixmaps/speex_logo.xpm"
 
 /* MAINTENANCE:
  *
@@ -169,7 +177,7 @@ file_is_ogg_speex (const char * pathname)
 
   char * ogg_data;
 
-  SpeexMode *mode;
+  const SpeexMode *mode;
   SpeexHeader *header;
 
   fd = open (pathname, O_RDONLY);
@@ -237,7 +245,7 @@ process_header(ogg_packet *op, int enh_enabled, int * frame_size, int * rate,
   modeID = header->mode;
   if (forceMode!=-1)
     modeID = forceMode;
-  mode = speex_mode_list[modeID];
+  mode = (SpeexMode *)speex_mode_list[modeID];
 
 #ifdef HAVE_SPEEX_BETA4
   if (header->speex_version_id > 1) {
@@ -682,7 +690,7 @@ static int
 speex_sample_save_thread (sw_op_instance * inst)
 {
   sw_sample * sample = inst->sample;
-  char * pathname = (char *)inst->do_data;
+  gchar * pathname = (gchar *)inst->do_data;
 
   FILE * outfile;
   sw_format * format;
@@ -699,7 +707,7 @@ speex_sample_save_thread (sw_op_instance * inst)
   ogg_packet       op; /* one raw packet of data for decode */
 
   float input[MAX_FRAME_SIZE];
-  char cbits[MAX_FRAME_BYTES];
+  gchar cbits[MAX_FRAME_BYTES];
   int nbBytes;
   int id = 0;
 
@@ -709,8 +717,8 @@ speex_sample_save_thread (sw_op_instance * inst)
   void * st;
   SpeexBits bits;
 
-  char * vendor_string = "Encoded with Sweep " VERSION " (metadecks.org)";
-  char * comments = NULL;
+  gchar * vendor_string = "Encoded with Sweep " VERSION " (metadecks.org)";
+  gchar * comments = NULL;
   int comments_length = 0;
 
   int eos = 0;
@@ -751,18 +759,18 @@ speex_sample_save_thread (sw_op_instance * inst)
 
   switch (so->mode) {
   case MODE_NARROWBAND:
-    mode = &speex_nb_mode;
+    mode = (SpeexMode *) &speex_nb_mode;
     break;
   case MODE_WIDEBAND:
-    mode = &speex_wb_mode;
+    mode = (SpeexMode *) &speex_wb_mode;
     break;
 #if (SPEEX_NB_MODES > 2)
   case MODE_ULTRAWIDEBAND:
-    mode = &speex_uwb_mode;
+    mode = (SpeexMode *) &speex_uwb_mode;
     break;
 #endif
   default:
-    mode = &speex_nb_mode;
+    mode = (SpeexMode *) &speex_nb_mode;
     break;
   }
 
@@ -1076,7 +1084,7 @@ speex_save_options_dialog_ok_cb (GtkWidget * widget, gpointer data)
   speex_save_options * so;
   GtkWidget * checkbutton;
   GtkWidget * entry;
-  gchar * text;
+  const gchar * text;
 
   gboolean use_br;
   GtkObject * adj; 
@@ -1094,50 +1102,50 @@ speex_save_options_dialog_ok_cb (GtkWidget * widget, gpointer data)
   /* Mode */
 
   mode =
-    GPOINTER_TO_INT(gtk_object_get_data (GTK_OBJECT(dialog), "mode_choice"));
+    GPOINTER_TO_INT(g_object_get_data (G_OBJECT(dialog), "mode_choice"));
 
   /* Features */
 
   features =
-    GPOINTER_TO_INT(gtk_object_get_data (GTK_OBJECT(dialog),
+    GPOINTER_TO_INT(g_object_get_data (G_OBJECT(dialog),
 					 "features_choice"));
 
-  adj = GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "quality_adj"));
+  adj = GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "quality_adj"));
   quality = (int)GTK_ADJUSTMENT(adj)->value;
 
-  adj = GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "complexity_adj"));
+  adj = GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "complexity_adj"));
   complexity = (int)GTK_ADJUSTMENT(adj)->value;
 
-  adj = GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "framepack_adj"));
+  adj = GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "framepack_adj"));
   framepack = (int)GTK_ADJUSTMENT(adj)->value;
 
   checkbutton =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "br_chb"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "br_chb"));
   use_br = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(checkbutton));
 
   entry =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "br_entry"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "br_entry"));
   text = gtk_entry_get_text (GTK_ENTRY(entry));
   bitrate = (int)strtol (text, (char **)NULL, 0);
 
   /* rem encode */
   checkbutton =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "rem_encode_chb"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "rem_encode_chb"));
   rem_encode =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(checkbutton));
 
   entry =
-    GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(dialog), "serialno_entry"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "serialno_entry"));
   text = gtk_entry_get_text (GTK_ENTRY(entry));
   serialno = strtol (text, (char **)NULL, 0);
   if (serialno == LONG_MIN || serialno == LONG_MAX) serialno = random ();
 
   checkbutton =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "rem_serialno_chb"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "rem_serialno_chb"));
   rem_serialno =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(checkbutton));
 
-  pathname = gtk_object_get_data (GTK_OBJECT(dialog), "pathname");
+  pathname = g_object_get_data (G_OBJECT(dialog), "pathname");
 
   gtk_widget_destroy (dialog);
 
@@ -1254,28 +1262,28 @@ speex_encode_options_update_cb (GtkWidget * widget, gpointer data)
 
   /* Features */
   features =
-    GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT(dialog),
+    GPOINTER_TO_INT (g_object_get_data (G_OBJECT(dialog),
 					  "features_choice"));
 
   /* Quality */
 
   quality_label =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "quality_label"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "quality_label"));
   quality_hscale =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "quality_hscale"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "quality_hscale"));
 
   /* Bitrate */
 
   br_checkbutton =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "br_chb"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "br_chb"));
   br = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(br_checkbutton));
 
   br_label =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "br_label"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "br_label"));
   br_entry =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "br_entry"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "br_entry"));
   br_units =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "br_units"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "br_units"));
 
   gtk_widget_set_sensitive (br_label, br);
   gtk_widget_set_sensitive (br_entry, br);
@@ -1299,9 +1307,9 @@ speex_encode_options_mode_cb (GtkWidget * widget, gpointer data)
   GtkWidget * dialog = GTK_WIDGET (data);
   int mode;
 
-  mode = GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(widget)));
+  mode = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(widget), "default"));
 
-  gtk_object_set_data (GTK_OBJECT(dialog), "mode_choice",
+  g_object_set_data (G_OBJECT(dialog), "mode_choice",
 		       GINT_TO_POINTER(mode));
 }
 
@@ -1316,7 +1324,7 @@ speex_encode_options_mode_auto_cb (GtkWidget * widget, gpointer data)
 
   dialog = gtk_widget_get_toplevel (widget);
   option_menu =
-    GTK_OPTION_MENU(gtk_object_get_data (GTK_OBJECT(dialog), "mode_menu"));
+    GTK_OPTION_MENU(g_object_get_data (G_OBJECT(dialog), "mode_menu"));
 
 #if (SPEEX_NB_MODES > 2)
   if (f->rate >= 32000) {
@@ -1330,7 +1338,7 @@ speex_encode_options_mode_auto_cb (GtkWidget * widget, gpointer data)
     }
 
   gtk_option_menu_set_history (option_menu, mode);
-  gtk_object_set_data (GTK_OBJECT(dialog), "mode_choice",
+  g_object_set_data (G_OBJECT(dialog), "mode_choice",
 		       GINT_TO_POINTER(mode));
 }
 
@@ -1341,14 +1349,14 @@ speex_encode_options_set_features (GtkWidget * dialog, int features)
   int i;
 
   option_menu =
-    GTK_OPTION_MENU(gtk_object_get_data (GTK_OBJECT(dialog), "features_menu"));
+    GTK_OPTION_MENU(g_object_get_data (G_OBJECT(dialog), "features_menu"));
 
   for (i = 0; feature_choices[i].name != NULL; i++) {
     if (feature_choices[i].number == features)
       gtk_option_menu_set_history (option_menu, i);
   }
 
-  gtk_object_set_data (GTK_OBJECT(dialog), "features_choice",
+  g_object_set_data (G_OBJECT(dialog), "features_choice",
 		       GINT_TO_POINTER(features));
 }
 
@@ -1358,9 +1366,9 @@ speex_encode_options_features_cb (GtkWidget * widget, gpointer data)
   GtkWidget * dialog = GTK_WIDGET (data);
   int features;
 
-  features = GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(widget)));
+  features = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(widget), "default"));
 
-  gtk_object_set_data (GTK_OBJECT(dialog), "features_choice",
+  g_object_set_data (G_OBJECT(dialog), "features_choice",
 		       GINT_TO_POINTER(features));
 
   speex_encode_options_update_cb (dialog, data);
@@ -1393,7 +1401,7 @@ speex_encode_options_reset_cb (GtkWidget * widget, gpointer data)
 
   /* Quality */
 
-  adj = GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "quality_adj"));
+  adj = GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "quality_adj"));
   
   i = prefs_get_int (QUALITY_KEY);
   
@@ -1407,7 +1415,7 @@ speex_encode_options_reset_cb (GtkWidget * widget, gpointer data)
 
   /* Complexity */
 
-  adj = GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "complexity_adj"));
+  adj = GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "complexity_adj"));
   
   i = prefs_get_int (COMPLEXITY_KEY);
   
@@ -1421,7 +1429,7 @@ speex_encode_options_reset_cb (GtkWidget * widget, gpointer data)
 
   /* Framepack */
 
-  adj = GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "framepack_adj"));
+  adj = GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "framepack_adj"));
   
   i = prefs_get_int (FRAMEPACK_KEY);
   
@@ -1454,18 +1462,18 @@ speex_encode_options_default_cb (GtkWidget * widget, gpointer data)
 
   /* Quality */
   quality_adj =
-    GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "quality_adj"));
+    GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "quality_adj"));
   gtk_adjustment_set_value (GTK_ADJUSTMENT(quality_adj), DEFAULT_QUALITY);
 
   /* Complexity */
   complexity_adj =
-    GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "complexity_adj"));
+    GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "complexity_adj"));
   gtk_adjustment_set_value (GTK_ADJUSTMENT(complexity_adj),
 			    DEFAULT_COMPLEXITY);
 
   /* Framepack */
   framepack_adj =
-    GTK_OBJECT(gtk_object_get_data (GTK_OBJECT(dialog), "framepack_adj"));
+    GTK_OBJECT(g_object_get_data (G_OBJECT(dialog), "framepack_adj"));
   gtk_adjustment_set_value (GTK_ADJUSTMENT(framepack_adj), DEFAULT_FRAMEPACK);
 
   speex_encode_options_update_cb (widget, data);
@@ -1510,11 +1518,11 @@ randomise_serialno_pressed_cb (GtkWidget * widget, gpointer data)
   dialog = gtk_widget_get_toplevel (widget);
 
   checkbutton =
-    GTK_WIDGET(gtk_object_get_data (GTK_OBJECT(dialog), "rem_serialno_chb"));
+    GTK_WIDGET(g_object_get_data (G_OBJECT(dialog), "rem_serialno_chb"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(checkbutton), FALSE);
 
   tag = gtk_timeout_add (30, randomise_serialno, data);
-  gtk_object_set_data (GTK_OBJECT(widget), "tag", GINT_TO_POINTER(tag));
+  g_object_set_data (G_OBJECT(widget), "tag", GINT_TO_POINTER(tag));
 }
 
 static void
@@ -1522,7 +1530,7 @@ randomise_serialno_released_cb (GtkWidget * widget, gpointer data)
 {
   gint tag;
 
-  tag = GPOINTER_TO_INT(gtk_object_get_data (GTK_OBJECT(widget), "tag"));
+  tag = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(widget), "tag"));
   gtk_timeout_remove (tag);
 }
 
@@ -1557,12 +1565,10 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   GtkWidget * entry;
 
   GtkWidget * separator;
-
-  GtkAccelGroup * accel_group;
-
   GtkTooltips * tooltips;
+  GtkWidget *speex_logo;
 
-  GtkStyle * style;
+/*  GtkStyle * style; */
 
   int i;
   long * l;
@@ -1571,26 +1577,11 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_window_set_title (GTK_WINDOW(dialog),
 			_("Sweep: Speex save options"));
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
+  sweep_set_window_icon(GTK_WINDOW(dialog));
 
-  accel_group = gtk_accel_group_new ();
-  gtk_window_add_accel_group (GTK_WINDOW(dialog), accel_group);
+  attach_window_close_accel(GTK_WINDOW(dialog));
 
-#ifdef DEVEL_CODE
-  /* XXX: Use of this accelerator gives the following error messages:
-
-  Gtk-CRITICAL **: file gtkstyle.c: line 568 (gtk_style_detach): assertion `style != NULL' failed.
-
-  Gtk-CRITICAL **: file gtkcontainer.c: line 1247 (gtk_container_unregister_toplevel): assertion `node != NULL' failed.
-
-  Gtk-CRITICAL **: file gtkstyle.c: line 621 (gtk_style_unref): assertion `style != NULL' failed.
-
-  */
-
-  gtk_accel_group_add (accel_group, GDK_w, GDK_CONTROL_MASK, GDK_NONE,
-		       GTK_OBJECT(dialog), "destroy");
-#endif
-
-  gtk_object_set_data (GTK_OBJECT(dialog), "pathname", pathname);
+  g_object_set_data (G_OBJECT(dialog), "pathname", pathname);
 
   main_vbox = GTK_DIALOG(dialog)->vbox;
 
@@ -1603,7 +1594,6 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_container_add (GTK_CONTAINER(ebox), vbox);
   gtk_widget_show (vbox);
 
-#if 0
   /* Ogg Speex pixmaps */
 
   hbox = gtk_hbox_new (FALSE, 0);
@@ -1611,33 +1601,26 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_container_set_border_width (GTK_CONTAINER(hbox), 4);
   gtk_widget_show (hbox);
 
-  pixmap = create_widget_from_xpm (dialog, white_ogg_xpm);
-  gtk_box_pack_start (GTK_BOX(hbox), pixmap, FALSE, FALSE, 0);
-  gtk_widget_show (pixmap);
+  speex_logo = create_widget_from_xpm (dialog, speex_logo_xpm);
+  gtk_box_pack_start (GTK_BOX(hbox), speex_logo, FALSE, FALSE, 0);
+  gtk_widget_show (speex_logo);
 
-  pixmap = create_widget_from_xpm (dialog, speexword2_xpm);
-  gtk_box_pack_start (GTK_BOX(hbox), pixmap, FALSE, FALSE, 0);
-  gtk_widget_show (pixmap);
-#endif
+   /* filename */
 
-  /* filename */
-
-  hbox = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER(hbox), 4);
-  gtk_widget_show (hbox);
+  
+/* worth changing this over to pango?
 
   style = gtk_style_new ();
   gdk_font_unref (style->font);
   style->font =
-    gdk_font_load("-*-helvetica-medium-r-normal-*-*-180-*-*-*-*-*-*");
+  gdk_font_load("-*-helvetica-medium-r-normal-*-*-180-*-*-*-*-*-*");
   gtk_widget_push_style (style);
-
+*/
   label = gtk_label_new (g_basename (pathname));
-  gtk_box_pack_start (GTK_BOX(hbox), label, TRUE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(vbox), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
   
-  gtk_widget_pop_style ();
+/* gtk_widget_pop_style (); */
 
   notebook = gtk_notebook_new ();
   gtk_box_pack_start (GTK_BOX(main_vbox), notebook, TRUE, TRUE, 4);
@@ -1670,22 +1653,22 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
     menuitem =
       gtk_menu_item_new_with_label (_(mode_choices[i].name));
     gtk_menu_append (GTK_MENU(menu), menuitem);
-    gtk_object_set_user_data (GTK_OBJECT(menuitem),
+    g_object_set_data (G_OBJECT(menuitem), "default", 
 			      GINT_TO_POINTER(mode_choices[i].number));
     gtk_widget_show (menuitem);
 
-    gtk_signal_connect (GTK_OBJECT(menuitem), "activate",
-			GTK_SIGNAL_FUNC(speex_encode_options_mode_cb),
+    g_signal_connect (G_OBJECT(menuitem), "activate",
+			G_CALLBACK(speex_encode_options_mode_cb),
 			dialog);
   }
   gtk_option_menu_set_menu (GTK_OPTION_MENU(option_menu), menu);
     
-  gtk_object_set_data (GTK_OBJECT(dialog), "mode_menu", option_menu);
+  g_object_set_data (G_OBJECT(dialog), "mode_menu", option_menu);
 
   button = gtk_button_new_with_label (_("Auto"));
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 4);
-  gtk_signal_connect (GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(speex_encode_options_mode_auto_cb),
+  g_signal_connect (G_OBJECT(button), "clicked",
+		      G_CALLBACK(speex_encode_options_mode_auto_cb),
 		      sample);
   gtk_widget_show (button);
   
@@ -1711,12 +1694,12 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
     menuitem =
       gtk_menu_item_new_with_label (_(feature_choices[i].name));
     gtk_menu_append (GTK_MENU(menu), menuitem);
-    gtk_object_set_user_data (GTK_OBJECT(menuitem),
+    g_object_set_data (G_OBJECT(menuitem), "default", 
 			      GINT_TO_POINTER(feature_choices[i].number));
     gtk_widget_show (menuitem);
 
-    gtk_signal_connect (GTK_OBJECT(menuitem), "activate",
-			GTK_SIGNAL_FUNC(speex_encode_options_features_cb),
+    g_signal_connect (G_OBJECT(menuitem), "activate",
+			G_CALLBACK(speex_encode_options_features_cb),
 			dialog);
 
     if (feature_choices[i].desc != NULL) {
@@ -1727,7 +1710,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   }
   gtk_option_menu_set_menu (GTK_OPTION_MENU(option_menu), menu);
     
-  gtk_object_set_data (GTK_OBJECT(dialog), "features_menu", option_menu);
+  g_object_set_data (G_OBJECT(dialog), "features_menu", option_menu);
 
 
   table = gtk_table_new (3, 2, TRUE);
@@ -1748,7 +1731,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 4);
   gtk_widget_show (label);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "quality_label", label);
+  g_object_set_data (G_OBJECT (dialog), "quality_label", label);
 
   quality_adj = gtk_adjustment_new (DEFAULT_QUALITY, /* value */
 				    1.0,  /* lower */
@@ -1777,7 +1760,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
     gtk_widget_set_usize (quality_hscale, gdk_screen_width() / 8, -1);
     gtk_widget_show (quality_hscale);
 
-    gtk_object_set_data (GTK_OBJECT (dialog), "quality_hscale",
+    g_object_set_data (G_OBJECT (dialog), "quality_hscale",
 			 quality_hscale);
 
     label = gtk_label_new (NULL);
@@ -1792,7 +1775,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 			  "file)."),
 			NULL);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "quality_adj", quality_adj);
+  g_object_set_data (G_OBJECT (dialog), "quality_adj", quality_adj);
 
   /* Bit rate */
 
@@ -1802,11 +1785,11 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 		    GTK_FILL|GTK_EXPAND, GTK_SHRINK, 0, 0);
   gtk_widget_show (checkbutton);
 
-  gtk_signal_connect (GTK_OBJECT(checkbutton), "toggled",
-		      GTK_SIGNAL_FUNC(speex_encode_options_update_cb),
+  g_signal_connect (G_OBJECT(checkbutton), "toggled",
+		      G_CALLBACK(speex_encode_options_update_cb),
 		      dialog);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "br_chb", checkbutton);
+  g_object_set_data (G_OBJECT (dialog), "br_chb", checkbutton);
 
   tooltips = gtk_tooltips_new ();
   gtk_tooltips_set_tip (tooltips, checkbutton,
@@ -1820,7 +1803,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 		    GTK_FILL|GTK_EXPAND, GTK_SHRINK, 0, 0);
   gtk_widget_show (label);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "br_label", label);
+  g_object_set_data (G_OBJECT (dialog), "br_label", label);
 
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_table_attach (GTK_TABLE(table), hbox, 1, 2, 2, 3,
@@ -1831,13 +1814,13 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_box_pack_start (GTK_BOX(hbox), entry, TRUE, TRUE, 0);
   gtk_widget_show (entry);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "br_entry", entry);
+  g_object_set_data (G_OBJECT (dialog), "br_entry", entry);
 
   label = gtk_label_new (_("bps"));
   gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 4);
   gtk_widget_show (label);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "br_units", label);
+  g_object_set_data (G_OBJECT (dialog), "br_units", label);
 
   label = gtk_label_new (_("Extra"));
 
@@ -1905,7 +1888,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 			  "and 10 (slower encoding)"),
 			NULL);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "complexity_adj", complexity_adj);
+  g_object_set_data (G_OBJECT (dialog), "complexity_adj", complexity_adj);
 
   /* Frames per packet */
 
@@ -1947,7 +1930,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 			  "bitrates."),
 			NULL);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "framepack_adj", framepack_adj);
+  g_object_set_data (G_OBJECT (dialog), "framepack_adj", framepack_adj);
 
   /* Remember / Reset */
 
@@ -1961,7 +1944,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_box_pack_start (GTK_BOX (hbox), checkbutton, TRUE, TRUE, 0);
   gtk_widget_show (checkbutton);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "rem_encode_chb", checkbutton);
+  g_object_set_data (G_OBJECT (dialog), "rem_encode_chb", checkbutton);
 
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(checkbutton), TRUE);
 
@@ -1971,8 +1954,8 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 
   button = gtk_button_new_with_label (_("Reset"));
   gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 4);
-  gtk_signal_connect (GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(speex_encode_options_reset_cb), sample);
+  g_signal_connect (G_OBJECT(button), "clicked",
+		      G_CALLBACK(speex_encode_options_reset_cb), sample);
   gtk_widget_show (button);
 
   tooltips = gtk_tooltips_new ();
@@ -1985,8 +1968,8 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 
   button = gtk_button_new_with_label (_("Defaults"));
   gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 4);
-  gtk_signal_connect (GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(speex_encode_options_default_cb),
+  g_signal_connect (G_OBJECT(button), "clicked",
+		      G_CALLBACK(speex_encode_options_default_cb),
 		      sample);
   gtk_widget_show (button);
 
@@ -2018,7 +2001,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 4);
   gtk_widget_show (entry);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "serialno_entry", entry);
+  g_object_set_data (G_OBJECT (dialog), "serialno_entry", entry);
 
   /* Remember serialno ? */
 
@@ -2035,8 +2018,8 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_box_pack_start (GTK_BOX (hbox), checkbutton, FALSE, TRUE, 0);
   gtk_widget_show (checkbutton);
 
-  gtk_signal_connect (GTK_OBJECT(checkbutton), "toggled",
-		      GTK_SIGNAL_FUNC(remember_serialno_clicked_cb),
+  g_signal_connect (G_OBJECT(checkbutton), "toggled",
+		      G_CALLBACK(remember_serialno_clicked_cb),
 		      sample);
 
   tooltips = gtk_tooltips_new ();
@@ -2054,7 +2037,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 			  "will be randomly generated for each file encoded."),
 			NULL);
 
-  gtk_object_set_data (GTK_OBJECT (dialog), "rem_serialno_chb", checkbutton);
+  g_object_set_data (G_OBJECT (dialog), "rem_serialno_chb", checkbutton);
 
   l = prefs_get_long (SERIALNO_KEY);
 
@@ -2080,12 +2063,12 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 			  "this button is held down."),
 			NULL);
 
-  gtk_signal_connect (GTK_OBJECT(button), "pressed",
-		      GTK_SIGNAL_FUNC(randomise_serialno_pressed_cb),
+  g_signal_connect (G_OBJECT(button), "pressed",
+		      G_CALLBACK(randomise_serialno_pressed_cb),
 		      entry);
 
-  gtk_signal_connect (GTK_OBJECT(button), "released",
-		      GTK_SIGNAL_FUNC(randomise_serialno_released_cb),
+  g_signal_connect (G_OBJECT(button), "released",
+		      G_CALLBACK(randomise_serialno_released_cb),
 		      entry);
 
   /* About */
@@ -2144,8 +2127,8 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->action_area), ok_button,
 		      TRUE, TRUE, 0);
   gtk_widget_show (ok_button);
-  gtk_signal_connect (GTK_OBJECT(ok_button), "clicked",
-		      GTK_SIGNAL_FUNC (speex_save_options_dialog_ok_cb),
+  g_signal_connect (G_OBJECT(ok_button), "clicked",
+		      G_CALLBACK (speex_save_options_dialog_ok_cb),
 		      sample);
 
   /* Cancel */
@@ -2155,8 +2138,8 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->action_area), button,
 		      TRUE, TRUE, 0);
   gtk_widget_show (button);
-  gtk_signal_connect (GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC (speex_save_options_dialog_cancel_cb),
+  g_signal_connect (G_OBJECT(button), "clicked",
+		      G_CALLBACK (speex_save_options_dialog_cancel_cb),
 		      sample);
 
   gtk_widget_grab_default (ok_button);
