@@ -35,14 +35,23 @@ create_style (GdkColor * fg, GdkColor * bg, gboolean do_grade);
 void
 init_styles (void);
 
+void
+sweep_set_window_icon (GtkWindow * window);
+
+
+
 GtkWidget *
 create_pixmap_button (GtkWidget * widget, gchar ** xpm_data,
 		      const gchar * tip_text, GtkStyle * style,
 		      sw_toolbar_button_type button_type,
-		      GtkSignalFunc clicked,
-		      GtkSignalFunc pressed, GtkSignalFunc released,
+		      GCallback clicked,
+		      GCallback pressed, GCallback released,
 		      gpointer data);
 
+
 GtkWidget* create_toolbox (void);
 
+void 
+attach_window_close_accel(GtkWindow *window);
+
 #endif /* __INTERFACE_H__ */
