@@ -24,6 +24,7 @@
 #endif
 
 #include <stdlib.h>
+#include <string.h>
 #include <time.h>
 
 #include <glib.h>
@@ -41,6 +42,7 @@
 #include "driver.h"
 #include "callbacks.h"
 #include "question_dialogs.h"
+#include "play.h"
 
 extern void sweep_timeouts_init (void);
 
@@ -58,8 +60,15 @@ static gint
 initial_sample_load (gpointer data)
 {
   char * arg = (char *)data;
+  gchar * pathname;
+
+  if (!strncmp (g_dirname (arg), ".", 1)) {
+    pathname = g_strdup_printf ("%s/%s", g_get_current_dir(), arg);
+  } else {
+    pathname = arg;
+  }
  
-  sample_load (arg);
+  sample_load (pathname);
 
   return FALSE;
 }
@@ -77,13 +86,13 @@ initial_sample_new (gpointer data)
 static gint
 initial_sample_ask (gpointer data)
 {
-  question_dialog_new (NULL, "Welcome to Sweep",
-		       "Hello, my name is Scrubby. "
-		       "Welcome to Sweep!\n\n"
-		       "Would you like to create a new file or "
-		       "load an existing file?",
+  question_dialog_new (NULL, _("Welcome to Sweep"),
+		       _("Hello, my name is Scrubby. "
+		         "Welcome to Sweep!\n\n"
+		         "Would you like to create a new file or "
+		         "load an existing file?"),
 		       _("Create new file"), _("Load existing file"),
-		       sample_new_empty_cb, NULL, sample_load_cb, NULL, 0);
+		       G_CALLBACK (sample_new_empty_cb), NULL, G_CALLBACK (sample_load_cb), NULL, 0);
 
   return FALSE;
 }
@@ -138,7 +147,9 @@ main (int argc, char *argv[])
 
   g_thread_init (NULL);
 
-  /* must be done before gtk_idle_add / gtk_timeout_add */
+	
+
+  /* must be done before g_idle_add / gtk_timeout_add */
   sweep_timeouts_init ();
 
   for(i = 1; i < argc; i++) {
@@ -165,7 +176,7 @@ main (int argc, char *argv[])
 #endif
       show_help = TRUE;
     } else {
-      gtk_idle_add ((GtkFunction)initial_sample_load, argv[i]);
+      g_idle_add ((GSourceFunc) initial_sample_load, argv[i]);
       no_files = FALSE;
     }
   }
@@ -196,7 +207,7 @@ main (int argc, char *argv[])
   
 
   if (no_files) {
-    gtk_idle_add ((GtkFunction)initial_sample_ask, NULL);
+    g_idle_add ((GSourceFunc)initial_sample_ask, NULL);
   }
 
   /* initialise preferences */
@@ -214,6 +225,9 @@ main (int argc, char *argv[])
   /* initialise devices */
   init_devices ();
 
+  /* init playback subsystem */
+  init_playback ();
+
 #if 0
   if (show_toolbox) {
     toolbox = create_toolbox ();
