@@ -26,16 +26,18 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
-#include <tdb.h>
 #include <glib.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <signal.h>
 #include <fcntl.h>
 #include <errno.h>
 
 #include <sweep/sweep_i18n.h>
 #include "question_dialogs.h"
 
+#include "tdb.h"
+
 static TDB_CONTEXT * prefs_tdb = NULL;
 
 #define DIR_MODE (S_IRWXU)
@@ -44,7 +46,7 @@ static TDB_CONTEXT * prefs_tdb = NULL;
 void
 prefs_init ()
 {
-  char * prefs_path;
+  G_CONST_RETURN char * prefs_path;
   struct stat sbuf;
   
   prefs_path = g_get_home_dir ();
